==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/escape/StackAlloc.h <==
// class org.dellroad.jc.cgen.escape.StackAlloc

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e19a02dee62a8866 org_dellroad_jc_cgen_escape_StackAlloc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_StackAlloc_H_
#define _JC_org_dellroad_jc_cgen_escape_StackAlloc_H_

// Forward structure declarations
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_AssignStmt$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$refs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object	_jc_org_dellroad_jc_cgen_escape_StackAlloc$object;

typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_StackAlloc$method$_init$3c88635eae989746(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods	org_dellroad_jc_cgen_escape_StackAlloc;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs {
	struct _jc_object	*stmt;
	struct _jc_object	*local;
	struct _jc_object	*value;
	struct _jc_java_lang_Boolean$object	*escapes;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$refs {
    _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs	org_dellroad_jc_cgen_escape_StackAlloc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs {
	jint	size;
	jint	cost;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs	org_dellroad_jc_cgen_escape_StackAlloc;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object {
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype _jc_org_dellroad_jc_cgen_escape_StackAlloc$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_StackAlloc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_StackAlloc$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_StackAlloc_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/escape/StackAlloc.h <==
// class org.dellroad.jc.cgen.escape.StackAlloc

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e19a02dee62a8866 org_dellroad_jc_cgen_escape_StackAlloc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_StackAlloc_H_
#define _JC_org_dellroad_jc_cgen_escape_StackAlloc_H_

// Forward structure declarations
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_AssignStmt$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$refs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object	_jc_org_dellroad_jc_cgen_escape_StackAlloc$object;

typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_StackAlloc$method$_init$3c88635eae989746(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vmethods	org_dellroad_jc_cgen_escape_StackAlloc;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs {
	struct _jc_object	*stmt;
	struct _jc_object	*local;
	struct _jc_object	*value;
	struct _jc_java_lang_Boolean$object	*escapes;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$refs {
    _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_refs	org_dellroad_jc_cgen_escape_StackAlloc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs {
	jint	size;
	jint	cost;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_escape_StackAlloc$sub_nonrefs	org_dellroad_jc_cgen_escape_StackAlloc;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_StackAlloc$object {
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_StackAlloc$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_StackAlloc$vtype _jc_org_dellroad_jc_cgen_escape_StackAlloc$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_StackAlloc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_StackAlloc$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_StackAlloc_H_ */
